parse_gaze: Decodes gaze information from passed parsed asc text

Description Usage Arguments Value

View source: R/eyelinkr-loading.R

Description

Used in case you load the text elsewhere or you just want to decode parts of it. In case you want to parse entire file, you can use read_gaze instead

Usage

1

Arguments

text

character vector of the asc file

Value

data.frame with the gaze


hejtmy/eyelinkr documentation built on Nov. 4, 2019, 1:31 p.m.